@@ -1,4 +1,3 @@
-// -*- c-basic-offset: 2 -*-
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
  * Copyright (C) 1999-2011 Licq developers
@@ -40,7 +39,6 @@
 #include <QFileDialog>
 #endif
 
-#include <licq/daemon.h>
 #include <licq/logging/logservice.h>
 #include <licq/logging/logutils.h>
 
@@ -98,7 +96,7 @@ LogWindow::LogWindow(QWidget* parent)
   adjustSize();
 
   myLogSink.reset(new PluginLogSink());
-  Licq::gDaemon.getLogService().registerLogSink(myLogSink);
+  Licq::gLogService.registerLogSink(myLogSink);
 
   sn = new QSocketNotifier(myLogSink->getReadPipe(), QSocketNotifier::Read, this);
   connect(sn, SIGNAL(activated(int)), SLOT(log(int)));
@@ -106,7 +104,7 @@ LogWindow::LogWindow(QWidget* parent)
 
 LogWindow::~LogWindow()
 {
-  Licq::gDaemon.getLogService().unregisterLogSink(myLogSink);
+  Licq::gLogService.unregisterLogSink(myLogSink);
 }
 
 void LogWindow::log(int /*fd*/)
