@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 2000-2010 Licq developers
+ * Copyright (C) 2000-2011 Licq developers
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,6 +24,7 @@
 #include <climits>
 #include <cstdio>
 #include <cstring>
+#include <sstream>
 #include <sys/select.h>
 #include <sys/time.h>
 #include <sys/types.h>
@@ -36,17 +37,18 @@
 #include <licq/contactlist/usermanager.h>
 #include <licq/daemon.h>
 #include <licq/event.h>
-#include <licq/icq.h>
-#include <licq/icqdefines.h>
+#include <licq/icq/icq.h>
 #include <licq/inifile.h>
 #include <licq/logging/log.h>
 #include <licq/logging/logservice.h>
 #include <licq/logging/logutils.h>
-#include <licq/pluginmanager.h>
+#include <licq/plugin/pluginmanager.h>
 #include <licq/pluginsignal.h>
 #include <licq/protocolmanager.h>
 #include <licq/userevents.h>
 
+#include "pluginversion.h"
+
 using namespace std;
 using Licq::UserId;
 using Licq::gLog;
@@ -54,8 +56,6 @@ using Licq::gPluginManager;
 using Licq::gProtocolManager;
 using Licq::gUserManager;
 
-extern "C" { const char *LP_Version(); }
-
 CLicqRMS *licqRMS = NULL;
 
 // 100 - information
@@ -176,12 +176,15 @@ static const unsigned short NUM_COMMANDS = sizeof(commands)/sizeof(*commands);
 /*---------------------------------------------------------------------------
  * CLicqRMS::Constructor
  *-------------------------------------------------------------------------*/
-CLicqRMS::CLicqRMS(bool bEnable, unsigned short nPort)
+CLicqRMS::CLicqRMS(Licq::GeneralPlugin::Params& p)
+  : GeneralPlugin(p),
+    m_bEnabled(true),
+    myPort(0),
+    myAuthProtocol(LICQ_PPID)
 {
+  licqRMS = this;
   server = NULL;
   m_bExit = false;
-  m_bEnabled = bEnable;
-  m_nPort = nPort;
 }
 
 
@@ -196,6 +199,65 @@ CLicqRMS::~CLicqRMS()
     delete *iter;
 }
 
+string CLicqRMS::name() const
+{
+  return "RMS";
+}
+
+string CLicqRMS::description() const
+{
+  return "Licq remote management server";
+}
+
+string CLicqRMS::version() const
+{
+  return PLUGIN_VERSION_STRING;
+}
+
+string CLicqRMS::usage() const
+{
+  return "Usage:  Licq [options] -p rms -- [ -h ] [ -d ]\n"
+      "         -h          : help\n"
+      "         -d          : start disabled\n";
+}
+
+string CLicqRMS::configFile() const
+{
+  return "licq_rms.conf";
+}
+
+bool CLicqRMS::isEnabled() const
+{
+  return m_bEnabled;
+}
+
+bool CLicqRMS::init(int argc, char** argv)
+{
+  //char *LocaleVal = new char;
+  //LocaleVal = setlocale (LC_ALL, "");
+  //bindtextdomain (PACKAGE, LOCALEDIR);
+  //textdomain (PACKAGE);
+
+  // parse command line for arguments
+  int i = 0;
+  while ( (i = getopt(argc, argv, "hdp:")) > 0)
+  {
+    switch (i)
+    {
+    case 'h':  // help
+      puts(usage().c_str());
+      return false;
+    case 'd': // enable
+      m_bEnabled = false;
+      break;
+    case 'p':
+      myPort = atol(optarg);
+      break;
+    }
+  }
+  return true;
+}
+
 /*---------------------------------------------------------------------------
  * CLicqRMS::Shutdown
  *-------------------------------------------------------------------------*/
@@ -204,42 +266,77 @@ void CLicqRMS::Shutdown()
   gLog.info("Shutting down remote manager server");
 
   if (myLogSink)
-    Licq::gDaemon.getLogService().unregisterLogSink(myLogSink);
-
-  gPluginManager.unregisterGeneralPlugin();
+    Licq::gLogService.unregisterLogSink(myLogSink);
 }
 
 
 /*---------------------------------------------------------------------------
  * CLicqRMS::Run
  *-------------------------------------------------------------------------*/
-int CLicqRMS::Run()
+int CLicqRMS::run()
 {
-  unsigned nPort;
+  setSignalMask(Licq::PluginSignal::SignalAll);
 
-  // Register with the daemon, we only want the update user signal
-  m_nPipe = gPluginManager.registerGeneralPlugin(Licq::PluginSignal::SignalAll);
-
-  Licq::IniFile conf("licq_rms.conf");
+  Licq::IniFile conf(configFile());
   if (conf.loadFile())
   {
     conf.setSection("RMS");
-    conf.get("Port", nPort, 0);
+
+    // Ignore port in config if given on command line
+    if (myPort == 0)
+      conf.get("Port", myPort, 0);
+
+    string protocolStr;
+    conf.get("AuthProtocol", protocolStr, "Licq");
+    if (protocolStr == "Config")
+    {
+      // Get user and password from config file
+      myAuthProtocol = 0;
+      conf.get("AuthUser", myAuthUser);
+      conf.get("AuthPassword", myAuthPassword);
+
+      // Make sure we got something instead of opening a security problem
+      if (myAuthUser.empty() || myAuthPassword.empty())
+      {
+        gLog.warning("Missing value for AuthUser or AuthPassword in configuration, "
+            "login will not be possible.");
+
+        // Dummy value that should never match any real protocol
+        myAuthProtocol = 1;
+      }
+    }
+    else if (protocolStr.size() == 4)
+    {
+      // Parse protocol id
+      myAuthProtocol = (protocolStr[0] << 24) | (protocolStr[1] << 16) |
+          (protocolStr[2] << 8) | (protocolStr[3]);
+    }
+    else
+    {
+      // Invalid
+      gLog.warning("Invalid value for AuthProtocol in configuration, "
+          "will use ICQ account.");
+      myAuthProtocol = LICQ_PPID;
+    }
   }
 
   server = new Licq::TCPSocket();
 
-  if (Licq::gDaemon.tcpPortsLow() != 0 && nPort == 0)
+  if (Licq::gDaemon.tcpPortsLow() != 0 && myPort == 0)
   {
     if (!Licq::gDaemon.StartTCPServer(server))
+    {
+      Shutdown();
       return 1;
+    }
   }
   else
   {
-    if (!server->StartServer(nPort))
+    if (!server->StartServer(myPort))
     {
       gLog.error("Could not start server on port %u, "
-                 "maybe this port is already in use?", nPort);
+          "maybe this port is already in use?", myPort);
+      Shutdown();
       return 1;
     };
   }
@@ -252,6 +349,8 @@ int CLicqRMS::Run()
   int l;
   int nResult;
 
+  int m_nPipe = getReadPipe();
+
   while (!m_bExit)
   {
     f = CRMSClient::sockman.socketSet();
@@ -313,9 +412,14 @@ int CLicqRMS::Run()
       }
     }
   }
+  Shutdown();
   return 0;
 }
 
+void CLicqRMS::destructor()
+{
+  delete this;
+}
 
 /*---------------------------------------------------------------------------
  * CLicqRMS::ProcessPipe
@@ -323,12 +427,12 @@ int CLicqRMS::Run()
 void CLicqRMS::ProcessPipe()
 {
   char buf;
-  read(m_nPipe, &buf, 1);
+  read(getReadPipe(), &buf, 1);
   switch (buf)
   {
     case Licq::GeneralPlugin::PipeSignal:
     {
-      Licq::PluginSignal* s = Licq::gDaemon.popPluginSignal();
+      Licq::PluginSignal* s = popSignal();
       if (m_bEnabled)
         ProcessSignal(s);
       delete s;
@@ -338,7 +442,7 @@ void CLicqRMS::ProcessPipe()
     case Licq::GeneralPlugin::PipeEvent:
     {
       // An event is pending (should never happen)
-      Licq::Event* e = Licq::gDaemon.PopPluginEvent();
+      Licq::Event* e = popEvent();
       if (m_bEnabled)
         ProcessEvent(e);
       delete e;
@@ -489,7 +593,7 @@ CRMSClient::CRMSClient(Licq::TCPSocket* sin)
   gLog.info("Client connected from %s", sock.getRemoteIpString().c_str());
   fs = fdopen(sock.Descriptor(), "r+");
   fprintf(fs, "Licq Remote Management Server v%s\n"
-     "%d Enter your UIN:\n", LP_Version(), CODE_ENTERxUIN);
+      "%d Enter your UIN:\n", licqRMS->version().c_str(), CODE_ENTERxUIN);
   fflush(fs);
 
   m_szCheckId = 0;
@@ -513,7 +617,7 @@ CRMSClient::~CRMSClient()
 /*---------------------------------------------------------------------------
  * CRMSClient::GetProtocol
  *-------------------------------------------------------------------------*/
-unsigned long CRMSClient::GetProtocol(const char *szData)
+unsigned long CRMSClient::getProtocol(const string& data)
 {
   unsigned long nPPID = 0;
 
@@ -521,9 +625,9 @@ unsigned long CRMSClient::GetProtocol(const char *szData)
   gPluginManager.getProtocolPluginsList(plugins);
   BOOST_FOREACH(Licq::ProtocolPlugin::Ptr plugin, plugins)
   {
-    if (strcasecmp(plugin->getName(), szData) == 0)
+    if (strcasecmp(plugin->name().c_str(), data.c_str()) == 0)
     {
-      nPPID = plugin->getProtocolId();
+      nPPID = plugin->protocolId();
       break;
     }
   }
@@ -534,10 +638,9 @@ unsigned long CRMSClient::GetProtocol(const char *szData)
 /*---------------------------------------------------------------------------
  * CRMSClient::ParseUser
  *-------------------------------------------------------------------------*/
-void CRMSClient::ParseUser(const char *szData)
+void CRMSClient::ParseUser(const string& strData)
 {
   myUserId = UserId();
-  string strData(szData);
   string::size_type nPos= strData.find_last_of(".");
   if (nPos == string::npos)
   {
@@ -545,7 +648,7 @@ void CRMSClient::ParseUser(const char *szData)
     gPluginManager.getProtocolPluginsList(plugins);
     BOOST_FOREACH(Licq::ProtocolPlugin::Ptr plugin, plugins)
     {
-      myUserId = UserId(data_arg, plugin->getProtocolId());
+      myUserId = UserId(data_arg, plugin->protocolId());
       if (gUserManager.userExists(myUserId))
         break;
     }
@@ -554,7 +657,7 @@ void CRMSClient::ParseUser(const char *szData)
   {
     string strId(strData, 0, strData.find_last_of("."));
     string strProtocol(strData, strData.find_last_of(".")+1, strData.size());
-    myUserId = UserId(strId, GetProtocol(strProtocol.c_str()));
+    myUserId = UserId(strId, getProtocol(strProtocol));
   }
 }
 
@@ -657,7 +760,7 @@ int CRMSClient::StateMachine()
   {
     case STATE_UIN:
     {
-      m_szCheckId = data_line ? strdup(data_line) : 0;
+      myLoginUser = data_line;
       fprintf(fs, "%d Enter your password:\n", CODE_ENTERxPASSWORD);
       fflush(fs);
       m_nState = STATE_PASSWORD;
@@ -665,13 +768,25 @@ int CRMSClient::StateMachine()
     }
     case STATE_PASSWORD:
     {
-      Licq::OwnerReadGuard o(LICQ_PPID);
-      if (!o.isLocked())
-        return -1;
+      bool ok;
+      string name;
+      if (licqRMS->myAuthProtocol == 0)
+      {
+        // User and password specified in RMS config
+        ok = (myLoginUser == licqRMS->myAuthUser &&
+            data_line == licqRMS->myAuthPassword);
+        name = myLoginUser;
+      }
+      else
+      {
+        // Check against protocol owner
+        Licq::OwnerReadGuard o(licqRMS->myAuthProtocol);
+        if (!o.isLocked())
+          return -1;
+        ok = (myLoginUser == o->accountId() && data_line == o->password());
+        name = o->getAlias();
+      }
 
-      bool ok = (o->accountId() == m_szCheckId && o->password() == data_line);
-      free(m_szCheckId);
-      m_szCheckId = 0;
       if (!ok)
       {
         gLog.info("Client failed validation from %s",
@@ -683,7 +798,7 @@ int CRMSClient::StateMachine()
       gLog.info("Client validated from %s",
           sock.getRemoteIpString().c_str());
       fprintf(fs, "%d Hello %s.  Type HELP for assistance.\n", CODE_HELLO,
-         o->getAlias().c_str());
+         name.c_str());
       fflush(fs);
       m_nState = STATE_COMMAND;
       break;
@@ -737,7 +852,8 @@ bool CRMSClient::AddLineToText()
 {
   if (data_line[0] == '.' && data_line[1] == '\0') return true;
 
-  m_nTextPos += sprintf(&m_szText[m_nTextPos], "%s\n", data_line);
+  myText += data_line;
+  myText += "\n";
 
   return false;
 }
@@ -775,13 +891,11 @@ int CRMSClient::Process_INFO()
 {
   char *szId = strdup(data_arg);
   NEXT_WORD(data_arg);
-  unsigned long nPPID = GetProtocol(data_arg);
+  unsigned long nPPID = getProtocol(data_arg);
 
   UserId userId = UserId(szId, nPPID);
 
   //XXX Handle the case when we have the owner
-  if (szId == 0)
-    m_nUin = strtoul(gUserManager.ownerUserId(LICQ_PPID).accountId().c_str(), (char**)NULL, 10);
 
   // Print the user info
   Licq::UserReadGuard u(userId);
@@ -829,11 +943,11 @@ int CRMSClient::Process_STATUS()
     gPluginManager.getProtocolPluginsList(plugins);
     BOOST_FOREACH(Licq::ProtocolPlugin::Ptr plugin, plugins)
     {
-      Licq::OwnerReadGuard o(plugin->getProtocolId());
+      Licq::OwnerReadGuard o(plugin->protocolId());
       if (o.isLocked())
       {
         fprintf(fs, "%d %s %s %s\n", CODE_STATUS, o->accountId().c_str(),
-            plugin->getName(), o->statusString().c_str());
+            plugin->name().c_str(), o->statusString().c_str());
       }
     }
     fprintf(fs, "%d\n", CODE_STATUSxDONE);
@@ -849,14 +963,14 @@ int CRMSClient::Process_STATUS()
     gPluginManager.getProtocolPluginsList(plugins);
     BOOST_FOREACH(Licq::ProtocolPlugin::Ptr plugin, plugins)
     {
-      changeStatus(plugin->getProtocolId(), data_arg);
+      changeStatus(plugin->protocolId(), data_arg);
     }
   }
   else
   {
     string strStatus(strData, 0, strData.find_last_of("."));
     string strProtocol(strData, strData.find_last_of(".")+1, strData.size());
-    unsigned long nPPID = GetProtocol(strProtocol.c_str());
+    unsigned long nPPID = getProtocol(strProtocol);
     char *szStatus = strdup(strStatus.c_str());
     changeStatus(nPPID, szStatus);
     free(szStatus);
@@ -1129,8 +1243,7 @@ int CRMSClient::Process_MESSAGE()
 
   ParseUser(data_arg);
 
-  m_szText[0] = '\0';
-  m_nTextPos = 0;
+  myText.clear();
 
   m_nState = STATE_ENTERxMESSAGE;
   return fflush(fs);
@@ -1139,9 +1252,8 @@ int CRMSClient::Process_MESSAGE()
 int CRMSClient::Process_MESSAGE_text()
 {
   //XXX Give a tag...
-  m_szText[strlen(m_szText) - 1] = '\0';
-  unsigned long tag = gProtocolManager.sendMessage(myUserId, m_szText,
-      true, ICQ_TCPxMSG_NORMAL);
+  myText.erase(myText.size() - 1);
+  unsigned long tag = gProtocolManager.sendMessage(myUserId, myText);
 
   fprintf(fs, "%d [%ld] Sending message to %s.\n", CODE_COMMANDxSTART,
       tag, myUserId.toString().c_str());
@@ -1175,8 +1287,8 @@ int CRMSClient::Process_MESSAGE_text()
 int CRMSClient::Process_URL()
 {
   ParseUser(data_arg);
-  
-  m_nTextPos = 0;
+
+  myText.clear();
 
   m_nState = STATE_ENTERxURL;
   return fflush(fs);
@@ -1185,13 +1297,12 @@ int CRMSClient::Process_URL()
 
 int CRMSClient::Process_URL_url()
 {
-  strcpy(m_szLine, data_line);
+  myLine = data_line;
 
   fprintf(fs, "%d Enter description, terminate with a . on a line by itself:\n",
      CODE_ENTERxTEXT);
 
-  m_szText[0] = '\0';
-  m_nTextPos = 0;
+  myText.clear();
 
   m_nState = STATE_ENTERxURLxDESCRIPTION;
   return fflush(fs);
@@ -1200,8 +1311,7 @@ int CRMSClient::Process_URL_url()
 
 int CRMSClient::Process_URL_text()
 {
-  unsigned long tag = gProtocolManager.sendUrl(myUserId, m_szLine,
-      m_szText, true, ICQ_TCPxMSG_NORMAL);
+  unsigned long tag = gProtocolManager.sendUrl(myUserId, myLine, myText);
 
   fprintf(fs, "%d [%ld] Sending URL to %s.\n", CODE_COMMANDxSTART,
       tag, myUserId.toString().c_str());
@@ -1243,7 +1353,7 @@ int CRMSClient::Process_SMS()
   fprintf(fs, "%d Enter NUMBER:\n", CODE_ENTERxLINE);
 
   m_nUin = nUin;
-  m_nTextPos = 0;
+  myText.clear();
 
   m_nState = STATE_ENTERxSMSxNUMBER;
   return fflush(fs);
@@ -1252,13 +1362,12 @@ int CRMSClient::Process_SMS()
 
 int CRMSClient::Process_SMS_number()
 {
-  strcpy(m_szLine, data_line);
+  myLine = data_line;
 
   fprintf(fs, "%d Enter message, terminate with a . on a line by itself:\n",
      CODE_ENTERxTEXT);
 
-  m_szText[0] = '\0';
-  m_nTextPos = 0;
+  myText.clear();
 
   m_nState = STATE_ENTERxSMSxMESSAGE;
   return fflush(fs);
@@ -1270,10 +1379,10 @@ int CRMSClient::Process_SMS_message()
   char id[16];
   snprintf(id, 16, "%lu", m_nUin);
   Licq::UserId userId(id, LICQ_PPID);
-  unsigned long tag = gLicqDaemon->icqSendSms(userId, m_szLine, m_szText);
+  unsigned long tag = gLicqDaemon->icqSendSms(userId, myLine, myText);
 
   fprintf(fs, "%d [%lu] Sending SMS to %lu (%s).\n", CODE_COMMANDxSTART,
-     tag, m_nUin, m_szLine);
+     tag, m_nUin, myLine.c_str());
 
   tags.push_back(tag);
   m_nState = STATE_COMMAND;
@@ -1307,8 +1416,7 @@ int CRMSClient::Process_AR()
   fprintf(fs, "%d Enter %sauto response, terminate with a . on a line by itself:\n",
      CODE_ENTERxTEXT, myUserId.isValid() ? "custom " : "");
 
-  m_szText[0] = '\0';
-  m_nTextPos = 0;
+  myText.clear();
 
   m_nState = STATE_ENTERxAUTOxRESPONSE;
   return fflush(fs);
@@ -1320,13 +1428,16 @@ int CRMSClient::Process_AR_text()
   {
     Licq::OwnerWriteGuard o(LICQ_PPID);
     if (o.isLocked())
-      o->setAutoResponse(m_szText);
+    {
+      o->setAutoResponse(myText);
+      o->save(Licq::Owner::SaveOwnerInfo);
+    }
   }
   else
   {
     Licq::UserWriteGuard u(myUserId);
     if (u.isLocked())
-      u->setCustomAutoResponse(m_szText);
+      u->setCustomAutoResponse(myText);
   }
 
   fprintf(fs, "%d Auto response saved.\n", CODE_RESULTxSUCCESS);
@@ -1350,7 +1461,7 @@ int CRMSClient::Process_LOG()
   if (!licqRMS->myLogSink)
   {
     licqRMS->myLogSink.reset(new Licq::PluginLogSink);
-    Licq::gDaemon.getLogService().registerLogSink(licqRMS->myLogSink);
+    Licq::gLogService.registerLogSink(licqRMS->myLogSink);
   }
 
   unsigned short lt = strtoul(data_arg, (char**)NULL, 10);
@@ -1443,59 +1554,53 @@ int CRMSClient::Process_VIEW()
 
 void CRMSClient::printUserEvent(const Licq::UserEvent* e, const string& alias)
 {
-  if (e)
-  {
-    char szEventHeader[75]; // Allows 50 chars for a nick
-    switch (e->SubCommand())
-    {
-      case ICQ_CMDxSUB_MSG:
-        sprintf(szEventHeader, "%d Message ", CODE_VIEWxMSG);
-        break;
-
-      case ICQ_CMDxSUB_URL:
-        sprintf(szEventHeader, "%d URL ", CODE_VIEWxURL);
-        break;
-
-      case ICQ_CMDxSUB_CHAT:
-        sprintf(szEventHeader, "%d Chat Request ", CODE_VIEWxCHAT);
-        break;
-
-      case ICQ_CMDxSUB_FILE:
-        sprintf(szEventHeader, "%d File Request ", CODE_VIEWxFILE);
-        break;
-
-      default:
-        sprintf(szEventHeader, "%d Unknown Event ", CODE_VIEWxUNKNOWN);
-    }
-
-    strcat(szEventHeader, "from ");
-    strncat(szEventHeader, alias.c_str(), 50);
-    strcat(szEventHeader, "\n\0");
-
-    // Write out the event header
-    fprintf(fs, "%s", szEventHeader);
-
-    // Timestamp
-    char szTimestamp[39];
-    char szTime[25];
-    time_t nMessageTime = e->Time();
-    struct tm *pTM = localtime(&nMessageTime);
-    strftime(szTime, 25, "%Y-%m-%d %H:%M:%S", pTM);
-    sprintf(szTimestamp, "%d Sent At ", CODE_VIEWxTIME);
-    strncat(szTimestamp, szTime, 25);
-    strcat(szTimestamp, "\n\0");
-    fprintf(fs, "%s", szTimestamp);
-
-    // Message
-    fprintf(fs, "%d Message Start\n", CODE_VIEWxTEXTxSTART);
-    fprintf(fs, "%s", e->text().c_str());
-    fprintf(fs, "\n");
-    fprintf(fs, "%d Message Complete\n", CODE_VIEWxTEXTxEND);
-  }
-  else
+  if (e == NULL)
   {
     fprintf(fs, "%d Invalid event\n", CODE_EVENTxERROR);
+    return;
   }
+
+  std::ostringstream eventHeader;
+  switch (e->eventType())
+  {
+    case Licq::UserEvent::TypeMessage:
+      eventHeader << CODE_VIEWxMSG << " Message";
+      break;
+
+    case Licq::UserEvent::TypeUrl:
+      eventHeader << CODE_VIEWxURL << " URL";
+      break;
+
+    case Licq::UserEvent::TypeChat:
+      eventHeader << CODE_VIEWxCHAT << " Chat Request";
+      break;
+
+    case Licq::UserEvent::TypeFile:
+      eventHeader << CODE_VIEWxFILE << " File Request";
+      break;
+
+    default:
+      eventHeader << CODE_VIEWxUNKNOWN << " Unknown Event";
+  }
+
+  eventHeader << " from ";
+  eventHeader << alias;
+  eventHeader << "\n";
+
+  // Write out the event header
+  fputs(eventHeader.str().c_str(), fs);
+
+  // Timestamp
+  char szTime[25];
+  time_t nMessageTime = e->Time();
+  struct tm* pTM = localtime(&nMessageTime);
+  strftime(szTime, 25, "%Y-%m-%d %H:%M:%S", pTM);
+  fprintf(fs, "%d Sent At %s\n", CODE_VIEWxTIME, szTime);
+
+  // Message
+  fprintf(fs, "%d Message Start\n", CODE_VIEWxTEXTxSTART);
+  fputs(e->text().c_str(), fs);
+  fprintf(fs, "\n%d Message Complete\n", CODE_VIEWxTEXTxEND);
 }
 
 /*---------------------------------------------------------------------------
@@ -1511,7 +1616,7 @@ int CRMSClient::Process_ADDUSER()
 {
   char *szId = strdup(data_arg);
   NEXT_WORD(data_arg);
-  unsigned long nPPID = GetProtocol(data_arg);
+  unsigned long nPPID = getProtocol(data_arg);
   UserId userId(szId, nPPID);
 
   if (gUserManager.addUser(userId) != 0)
