@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 2010 Licq developers
+ * Copyright (C) 2010-2011 Licq developers
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -40,8 +40,9 @@ public:
 
   ~Owner();
 
+protected:
   // From Licq::Owner
-  void SaveLicqInfo();
+  void saveOwnerInfo();
 };
 
 } // namespace LicqDaemon
