@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 2000-2010 Licq developers
+ * Copyright (C) 2000-2011 Licq developers
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,8 +24,8 @@
 
 #include <licq/logging/log.h>
 #include <licq/daemon.h>
-#include <licq/icqdefines.h>
 #include <licq/inifile.h>
+#include <licq/plugin/pluginmanager.h>
 #include <licq/pluginsignal.h>
 #include <licq/protocolsignal.h>
 
@@ -52,6 +52,7 @@ using Licq::UserReadGuard;
 using Licq::UserWriteGuard;
 using Licq::gDaemon;
 using Licq::gLog;
+using Licq::gPluginManager;
 using namespace LicqDaemon;
 
 // Declare global UserManager (internal for daemon)
@@ -101,7 +102,7 @@ void UserManager::addOwner(const UserId& userId)
   myOwners[userId.protocolId()] = o;
   myOwnerListMutex.unlockWrite();
 
-  gDaemon.pushPluginSignal(new PluginSignal(PluginSignal::SignalList,
+  gPluginManager.pushPluginSignal(new PluginSignal(PluginSignal::SignalList,
       PluginSignal::ListOwnerAdded, userId));
 }
 
@@ -226,9 +227,6 @@ bool UserManager::Load()
       gLog.warning(tr("Skipping user %i, empty key"), i);
       continue;
     }
-    string filename = User::ConfigDir;
-    filename += '/';
-    filename += userFile;
     size_t sz = userFile.rfind('.');
     if (sz == string::npos)
     {
@@ -241,7 +239,7 @@ bool UserManager::Load()
     unsigned long protocolId = (userFile[sz+1] << 24) | (userFile[sz+2] << 16) | (userFile[sz+3] << 8) | userFile[sz+4];
 
     UserId userId(accountId, protocolId);
-    User* u = new User(userId, filename);
+    User* u = new User(userId);
     u->AddToContactList();
     myUsers[userId] = u;
   }
@@ -262,7 +260,7 @@ void UserManager::saveUserList() const
     i->second->lockRead();
     bool temporary = i->second->NotInList();
     string accountId = i->second->accountId();
-    unsigned long ppid = i->second->ppid();
+    unsigned long ppid = i->second->protocolId();
     i->second->unlockRead();
 
     // Only save users that's been permanently added
@@ -273,9 +271,7 @@ void UserManager::saveUserList() const
     char key[20];
     sprintf(key, "User%i", count);
 
-    char ps[5];
-    Licq::protocolId_toStr(ps, ppid);
-    usersConf.set(key, accountId + "." + ps);
+    usersConf.set(key, accountId + "." + Licq::protocolId_toString(ppid));
   }
   usersConf.set("NumOfUsers", count);
   usersConf.writeFile();
@@ -308,7 +304,7 @@ bool UserManager::addUser(const UserId& uid,
     // Set this user to be on the contact list
     pUser->AddToContactList();
     //pUser->SetEnableSave(true);
-    pUser->saveAll();
+    pUser->save(User::SaveAll);
   }
 
   // Store the user in the lookup map
@@ -323,17 +319,17 @@ bool UserManager::addUser(const UserId& uid,
 
   // Notify plugins that user was added
   // Send this before adding user to server side as protocol code may generate updated signals
-  gDaemon.pushPluginSignal(new PluginSignal(PluginSignal::SignalList,
+  gPluginManager.pushPluginSignal(new PluginSignal(PluginSignal::SignalList,
       PluginSignal::ListUserAdded, uid, groupId));
 
+  // Set initial group membership but let add signal below update the server
+  if (groupId != 0)
+    setUserInGroup(uid, groupId, true, false);
+
   // Add user to server side list
   if (permanent && addToServer)
     gProtocolManager.addUser(uid, groupId);
 
-  // Set initial group membership, also sets server group for user
-  if (groupId != 0)
-    setUserInGroup(uid, groupId, true, permanent && addToServer);
-
   return true;
 }
 
@@ -355,7 +351,7 @@ bool UserManager::makeUserPermanent(const UserId& userId, bool addToServer,
     if (!user->NotInList())
       return false;
 
-    user->SetPermanent();
+    dynamic_cast<User*>(*user)->SetPermanent();
   }
 
   // Add user to server side list
@@ -398,7 +394,7 @@ void UserManager::removeUser(const UserId& userId, bool removeFromServer)
   delete u;
 
   // Notify plugins about the removed user
-  gDaemon.pushPluginSignal(new PluginSignal(PluginSignal::SignalList,
+  gPluginManager.pushPluginSignal(new PluginSignal(PluginSignal::SignalList,
       PluginSignal::ListUserRemoved, userId));
 }
 
@@ -433,7 +429,7 @@ void UserManager::RemoveOwner(unsigned long ppid)
   o->unlockWrite();
   delete o;
 
-  gDaemon.pushPluginSignal(new PluginSignal(PluginSignal::SignalList,
+  gPluginManager.pushPluginSignal(new PluginSignal(PluginSignal::SignalList,
       PluginSignal::ListOwnerRemoved, id));
 }
 
@@ -486,7 +482,7 @@ Licq::User* UserManager::fetchUser(const UserId& userId,
       myUsers[userId] = user;
 
       // Notify plugins that we added user to list
-      gDaemon.pushPluginSignal(new PluginSignal(PluginSignal::SignalList,
+      gPluginManager.pushPluginSignal(new PluginSignal(PluginSignal::SignalList,
           PluginSignal::ListUserAdded, userId));
 
       if (retWasAdded != NULL)
@@ -565,7 +561,7 @@ unsigned long UserManager::icqOwnerUin()
 
 void UserManager::notifyUserUpdated(const UserId& userId, unsigned long subSignal)
 {
-  gDaemon.pushPluginSignal(new PluginSignal(PluginSignal::SignalUser, subSignal, userId));
+  gPluginManager.pushPluginSignal(new PluginSignal(PluginSignal::SignalUser, subSignal, userId));
 }
 
 Group* UserManager::fetchGroup(int group, bool writeLock)
@@ -635,7 +631,7 @@ int UserManager::AddGroup(const string& name, unsigned short icqGroupId)
         name.c_str(), icqGroupId);
 
   // Send signal to let plugins know of the new group
-  gDaemon.pushPluginSignal(new PluginSignal(PluginSignal::SignalList,
+  gPluginManager.pushPluginSignal(new PluginSignal(PluginSignal::SignalList,
       PluginSignal::ListGroupAdded, UserId(), gid));
 
   return gid;
@@ -695,11 +691,11 @@ void UserManager::RemoveGroup(int groupId)
   }
 
   // Send signal to let plugins know of the removed group
-  gDaemon.pushPluginSignal(new PluginSignal(PluginSignal::SignalList,
+  gPluginManager.pushPluginSignal(new PluginSignal(PluginSignal::SignalList,
       PluginSignal::ListGroupRemoved, UserId(), groupId));
 
   // Send signal to let plugins know that sorting indexes may have changed
-  gDaemon.pushPluginSignal(new PluginSignal(PluginSignal::SignalList,
+  gPluginManager.pushPluginSignal(new PluginSignal(PluginSignal::SignalList,
       PluginSignal::ListGroupsReordered));
 }
 
@@ -739,7 +735,7 @@ void UserManager::ModifyGroupSorting(int groupId, int newIndex)
   myGroupListMutex.unlockRead();
 
   // Send signal to let plugins know that sorting indexes have changed
-  gDaemon.pushPluginSignal(new PluginSignal(PluginSignal::SignalList,
+  gPluginManager.pushPluginSignal(new PluginSignal(PluginSignal::SignalList,
       PluginSignal::ListGroupsReordered));
 }
 
@@ -778,7 +774,7 @@ bool UserManager::RenameGroup(int groupId, const string& name, bool sendUpdate)
     gIcqProtocol.icqRenameGroup(name, icqGroupId);
 
   // Send signal to let plugins know the group has changed
-  gDaemon.pushPluginSignal(new PluginSignal(PluginSignal::SignalList,
+  gPluginManager.pushPluginSignal(new PluginSignal(PluginSignal::SignalList,
       PluginSignal::ListGroupChanged, UserId(), groupId));
 
   return true;
@@ -971,7 +967,7 @@ void UserManager::SaveAllUsers()
   {
     Licq::UserWriteGuard u(user);
     if (!u->NotInList())
-      u->saveAll();
+      u->save(Licq::User::SaveAll);
   }
 }
 
@@ -1084,30 +1080,16 @@ void UserManager::setUserInGroup(const UserId& userId, int groupId,
     if (userId.protocolId() == LICQ_PPID)
     {
       if (inGroup) // Server group can only be changed, not removed
-        gIcqProtocol.icqChangeGroup(userId, groupId, gsid, ICQ_ROSTxNORMAL, ICQ_ROSTxNORMAL);
+        gIcqProtocol.icqChangeGroup(userId, groupId, gsid);
     }
     else
-      gDaemon.PushProtoSignal(new Licq::ProtoChangeUserGroupsSignal(userId), userId.protocolId());
+      gPluginManager.pushProtocolSignal(new Licq::ProtoChangeUserGroupsSignal(userId), userId.protocolId());
   }
 
   // Notify plugins
   notifyUserUpdated(userId, PluginSignal::UserGroups);
 }
 
-void UserManager::userStatusChanged(const UserId& userId, unsigned newStatus)
-{
-  Licq::UserWriteGuard u(userId);
-  if (u.isLocked())
-    u->statusChanged(newStatus);
-}
-
-void UserManager::ownerStatusChanged(unsigned long protocolId, unsigned newStatus)
-{
-  Licq::OwnerWriteGuard o(protocolId);
-  if (o.isLocked())
-    o->statusChanged(newStatus);
-}
-
 const string& UserManager::defaultUserEncoding()
 {
   return myDefaultEncoding;
